// Synchronous 8x32 Memory Design
// Specification:
//  Memory is 8-bits wide and address range is 0 to 31.
//  Memory access is synchronous.
//  Write data into the memory on posedge of clk when write=1
//  Place memory[addr] onto data bus on posedge of clk when read=1
//  The read and write signals should not be simultaneously high.
module mem ( input wire clk, write, read,
             input wire [4:0] addr,
	     inout wire [7:0] data
	   );

  logic [7:0] memory [0:31] ;
  logic [7:0] data_out;

  assign data = read ? data_out : 'z;

  always @(posedge clk)
    if (write && !read)
      #1step memory[addr] <= data;

  always_ff @(posedge clk iff ((read == '1)&&(write == '0)) )
       data_out <= memory[addr];

endmodule
